==============================================
Spike Pattern Detection and Evaluation (SPADE)
==============================================

.. automodule:: elephant.spade


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: spade
   :keyprefix: spade-
   :style: unsrt
